@@ -17,18 +17,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-location-entry.h 7828 2007-12-26 19:00:00Z diegoe $
  */
 
+#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
+#error "Only <epiphany/epiphany.h> can be included directly."
+#endif
+
 #ifndef EPHY_LOCATION_ENTRY_H
 #define EPHY_LOCATION_ENTRY_H
 
-#include "ephy-node.h"
-
-#include <gtk/gtkwidget.h>
-#include <gtk/gtktoolitem.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtkentrycompletion.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -39,8 +37,8 @@ G_BEGIN_DECLS
 #define EPHY_IS_LOCATION_ENTRY_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), EPHY_TYPE_LOCATION_ENTRY))
 #define EPHY_LOCATION_ENTRY_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), EPHY_TYPE_LOCATION_ENTRY, EphyLocationEntryClass))
 
-typedef struct _EphyLocationEntry		EphyLocationEntry;
 typedef struct _EphyLocationEntryClass		EphyLocationEntryClass;
+typedef struct _EphyLocationEntry		EphyLocationEntry;
 typedef struct _EphyLocationEntryPrivate	EphyLocationEntryPrivate;
 
 struct _EphyLocationEntryClass
@@ -67,29 +65,38 @@ GType		ephy_location_entry_get_type		(void);
 
 GtkWidget      *ephy_location_entry_new			(void);
 
-void		ephy_location_entry_set_completion	(EphyLocationEntry *le,
+void		ephy_location_entry_set_completion	(EphyLocationEntry *entry,
 							 GtkTreeModel *model,
 							 guint text_col,
 							 guint action_col,
 							 guint keywords_col,
 							 guint relevance_col,
+							 guint url_col,
 							 guint extra_col,
-							 guint favicon_col,
-							 guint url_col);
+							 guint favicon_col);
 
-void		ephy_location_entry_set_location	(EphyLocationEntry *le,
+void		ephy_location_entry_set_location	(EphyLocationEntry *entry,
 							 const char *address,
 							 const char *typed_address);
 
-void		ephy_location_entry_set_completion_func (EphyLocationEntry *le, 
-							 GtkEntryCompletionMatchFunc completion_func,
-							 gpointer user_data);
+void		ephy_location_entry_set_match_func	(EphyLocationEntry *entry, 
+							 GtkEntryCompletionMatchFunc match_func,
+							 gpointer user_data,
+							 GDestroyNotify notify);
 					
-const char     *ephy_location_entry_get_location	(EphyLocationEntry *le);
+const char     *ephy_location_entry_get_location	(EphyLocationEntry *entry);
+
+gboolean	ephy_location_entry_get_can_undo	(EphyLocationEntry *entry);
+
+gboolean	ephy_location_entry_get_can_redo	(EphyLocationEntry *entry);
+
+GSList         *ephy_location_entry_get_search_terms	(EphyLocationEntry *entry);
 
 gboolean	ephy_location_entry_reset		(EphyLocationEntry *entry);
 
-void		ephy_location_entry_activate		(EphyLocationEntry *le);
+void		ephy_location_entry_undo_reset		(EphyLocationEntry *entry);
+
+void		ephy_location_entry_activate		(EphyLocationEntry *entry);
 
 GtkWidget      *ephy_location_entry_get_entry		(EphyLocationEntry *entry);
 
