@@ -15,13 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-tree-model-node.h 6952 2007-03-11 19:42:02Z chpe $
  */
 
 #ifndef __EPHY_TREE_MODEL_NODE_H
 #define __EPHY_TREE_MODEL_NODE_H
 
-#include <gtk/gtktreemodel.h>
+#include <gtk/gtk.h>
 
 #include "ephy-node.h"
 
@@ -73,4 +72,8 @@ void               ephy_tree_model_node_iter_from_node   (EphyTreeModelNode *mod
 
 G_END_DECLS
 
+#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
+#error "Only <epiphany/epiphany.h> can be included directly."
+#endif
+
 #endif /* EPHY_TREE_MODEL_NODE_H */
