@@ -17,7 +17,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id$
  */
 
 #include "config.h"
@@ -128,13 +127,15 @@ enum
 	LAST_SIGNAL
 };
 
-static guint ephy_bookmarks_signals[LAST_SIGNAL] = { 0 };
+static guint ephy_bookmarks_signals[LAST_SIGNAL];
 
 static void ephy_bookmarks_class_init	(EphyBookmarksClass *klass);
 static void ephy_bookmarks_init		(EphyBookmarks *tab);
 static void ephy_bookmarks_finalize	(GObject *object);
 static char *impl_resolve_address	(EphyBookmarks*, const char*, const char*);
+#ifdef ENABLE_ZEROCONF
 static void ephy_local_bookmarks_start_client (EphyBookmarks *bookmarks);
+#endif
 
 G_DEFINE_TYPE_WITH_CODE (EphyBookmarks, ephy_bookmarks, G_TYPE_OBJECT,
 			 volatile GType flags_type; /* work around gcc's optimiser */
@@ -1220,32 +1221,20 @@ ephy_bookmarks_init (EphyBookmarks *eb)
 {
 	EphyNodeDb *db;
 
-	/* Translators: The text before the "|" is context to help you
-	 * decide on the correct translation. You MUST OMIT it in the
-	 * translated string. */
 	/* Translators: this topic contains all bookmarks */
-	const char *bk_all = Q_("bookmarks|All");
+	const char *bk_all = C_("bookmarks", "All");
 
-	/* Translators: The text before the "|" is context to help you
-	 * decide on the correct translation. You MUST OMIT it in the
-	 * translated string. */
 	/* Translators: this topic contains the most used bookmarks */
-	const char *bk_most_visited = Q_("bookmarks|Most Visited");
+	const char *bk_most_visited = C_("bookmarks", "Most Visited");
 
-	/* Translators: The text before the "|" is context to help you
-	 * decide on the correct translation. You MUST OMIT it in the
-	 * translated string. */
 	/* Translators: this topic contains the not categorized
 	   bookmarks */
-	const char *bk_not_categorized = Q_("bookmarks|Not Categorized");
+	const char *bk_not_categorized = C_("bookmarks", "Not Categorized");
 	
-#ifdef ENABLE_ZEROCONF	
-	/* Translators: The text before the "|" is context to help you
-	 * decide on the correct translation. You MUST OMIT it in the
-	 * translated string. */
+#ifdef ENABLE_ZEROCONF
 	/* Translators: this is an automatic topic containing local
 	 * websites bookmarks autodiscovered with zeroconf. */
-	const char *bk_local_sites = Q_("bookmarks|Nearby Sites");
+	const char *bk_local_sites = C_("bookmarks", "Nearby Sites");
 #endif
 
 	eb->priv = EPHY_BOOKMARKS_GET_PRIVATE (eb);
