@@ -25,7 +25,7 @@
 /* From GTK_CHECK_VERSION */
 #define EPHY_MAJOR_VERSION (2)
 #define EPHY_MINOR_VERSION (27)
-#define EPHY_MICRO_VERSION (1)
+#define EPHY_MICRO_VERSION (4)
 
 #define EPHY_CHECK_VERSION(major, minor, micro)\
   (EPHY_MAJOR_VERSION > (major) || \
@@ -35,14 +35,12 @@
 
 #include <epiphany/ephy-adblock.h>
 #include <epiphany/ephy-adblock-manager.h>
-#include <epiphany/ephy-base-embed.h>
 #include <epiphany/ephy-bookmarks.h>
 #include <epiphany/ephy-bookmarks-type-builtins.h>
 #include <epiphany/ephy-command-manager.h>
 #include <epiphany/ephy-dialog.h>
 #include <epiphany/ephy-embed-container.h>
 #include <epiphany/ephy-embed-event.h>
-#include <epiphany/ephy-embed-factory.h>
 #include <epiphany/ephy-embed.h>
 #include <epiphany/ephy-embed-persist.h>
 #include <epiphany/ephy-embed-prefs.h>
